SystemOrganization addCategory: #'MC2-Tests-Interface'!

MDFacadeTest subclass: #MDEnvironmentOpsTest
	instanceVariableNames: 'repository snapshot workspace slice environment'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Interface'!

!MDEnvironmentOpsTest methodsFor: 'constructing' stamp: 'cwp 2/10/2010 19:23'!
addToBoth: aVersion
	snapshot add: aVersion.
	repository add: aVersion! !

!MDEnvironmentOpsTest methodsFor: 'constructing' stamp: 'cwp 2/10/2010 19:23'!
addToRepository: aVersion
	repository add: aVersion! !

!MDEnvironmentOpsTest methodsFor: 'constructing' stamp: 'cwp 2/10/2010 19:23'!
addToSnapshot: aVersion
	snapshot add: aVersion! !

!MDEnvironmentOpsTest methodsFor: 'constructing' stamp: 'cwp 8/6/2010 16:12'!
prepare
	self prepare: 
		[self addToBoth: (self builder versionFor: #Alpha with: 'alpha').
		self addToBoth: (self builder versionFor: #Beta with: 'beta') ]! !

!MDEnvironmentOpsTest methodsFor: 'constructing' stamp: 'cwp 2/10/2010 19:29'!
prepare: aBlock
	| repositoryVersions |
	repository := Set new.
	snapshot := Set new.
	aBlock value.
	repositoryVersions := repository.
	repository := environment store.
	repositoryVersions do: [:ea | repository put: ea].
	snapshot := MDSnapshot withVersions: snapshot
	
	! !

!MDEnvironmentOpsTest methodsFor: 'running' stamp: 'cwp 7/20/2010 10:49'!
setUp
	environment := MDEnvironment new.
	slice := self slice.
	environment addSlice: slice.
	workspace := environment workspaceForSlice: slice.
	facade := workspace facade.! !

!MDEnvironmentOpsTest methodsFor: 'constructing' stamp: 'cwp 7/13/2010 16:05'!
slice
	^ (MDExplicitSlice forTesting)
		addElement: (self builder element: #Alpha);
		addElement: (self builder element: #Beta);
		yourself! !

!MDEnvironmentOpsTest methodsFor: 'tests' stamp: 'cwp 2/10/2010 19:30'!
testIncludeSnapshot
	self prepare.
	
	[ environment include: snapshot using: slice ] 
		on: MDMergeRequest
		do: [ :ex | ex merges do: [ :ea | ea applyTo: workspace ] ].
	self assertElementHasDefaultValue: #Alpha.
	self assertElementHasDefaultValue: #Beta! !

!MDEnvironmentOpsTest methodsFor: 'tests' stamp: 'cwp 8/6/2010 16:32'!
testSaveBundle
	| bundle |
	bundle := MDBundle forTesting.
	environment addSlice: bundle.
	bundle addSlice: slice.
	[environment save: bundle]
		on: MDCommentRequest
		do: [:ex | ex resume: 'test commit'].
	self assert: environment store memos size = 2! !

!MDEnvironmentOpsTest methodsFor: 'tests' stamp: 'cwp 8/6/2010 16:18'!
testSaveSlice
	
	[environment save: slice]
		on: MDCommentRequest
		do: [:ex | ex resume: 'test commit'].
	self assert: environment store memos size = 1! !

MDFacadeTest subclass: #MDMergeTest
	instanceVariableNames: 'workspace merge local remote'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Interface'!

!MDMergeTest methodsFor: 'running' stamp: 'cwp 7/20/2010 10:13'!
local: localVersion remote: remoteVersion
	local := localVersion.
	workspace loadVersion: local.
	remote := remoteVersion.
	merge := MDMerge toInclude: remote in: workspace.
! !

!MDMergeTest methodsFor: 'running' stamp: 'cwp 7/20/2010 10:12'!
setUp
	facade := MDFakeFacade new.
	workspace := MDWorkspace forFacade: facade.! !

!MDMergeTest methodsFor: 'tests' stamp: 'cwp 7/20/2010 10:12'!
testApplyLocal
	self local: (self builder versionWith: 'local') remote: (self builder versionWith: 'remote').
	merge chooseLocal.
	merge applyTo: workspace.
	self assertElementHasValue: 'local'! !

!MDMergeTest methodsFor: 'tests' stamp: 'cwp 7/20/2010 10:12'!
testApplyRemote
	self local: (self builder versionWith: 'local') remote: (self builder versionWith: 'remote').
	merge chooseRemote.
	merge applyTo: workspace.
	self assertElementHasValue: 'remote'! !

!MDMergeTest methodsFor: 'tests' stamp: 'cwp 7/13/2010 16:08'!
testChooseLocal
	self local: self builder version remote: self builder version.
	self assert: merge isConflict.
	merge chooseLocal.
	self assert: merge isLocal.
	self assert: merge resolution == local! !

!MDMergeTest methodsFor: 'tests' stamp: 'cwp 7/13/2010 16:08'!
testChooseRemote
	self local: self builder version remote: self builder version.
	self assert: merge isConflict.
	merge chooseRemote.
	self assert: merge isRemote.
	self assert: merge resolution == remote! !

!MDMergeTest methodsFor: 'tests' stamp: 'cwp 7/13/2010 16:08'!
testIsConflict
	self local: self builder version remote: self builder version.
	self assert: merge isConflict.
	self deny: merge isLocal.
	self deny: merge isRemote! !

!MDMergeTest methodsFor: 'tests' stamp: 'cwp 7/13/2010 16:08'!
testIsLocal
	remote := self builder version.
	local := self builder updateVersion: remote property: #one put: 'alpha2'.
	self local: local remote: remote.
	self assert: merge isLocal.
	self deny: merge isRemote.
	self deny: merge isConflict! !

!MDMergeTest methodsFor: 'tests' stamp: 'cwp 7/13/2010 16:08'!
testIsRemote
	local := self builder version.
	remote := self builder updateVersion: local property: #one put: 'alpha2'.
	self local: local remote: remote.
	self assert: merge isRemote.
	self deny: merge isLocal.
	self deny: merge isConflict! !

TestCase subclass: #MDAnnouncementTest
	instanceVariableNames: 'element slice received environment'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Interface'!

!MDAnnouncementTest methodsFor: 'accessing' stamp: 'cwp 8/18/2009 03:00'!
environment
	^ environment! !

!MDAnnouncementTest methodsFor: 'running' stamp: 'cwp 2/3/2010 23:05'!
setUp
	element := MDFakeElement named: #Alpha.
	environment := MDEnvironment forTesting.
	slice := environment addSlice: MDExplicitSlice forTesting.
	slice addElement: element.
	environment subscribe.
	received := OrderedCollection new.! !

!MDAnnouncementTest methodsFor: 'running' stamp: 'jf 11/19/2009 16:59'!
subscribeTo: aClass 
	self environment announcer
		observe: aClass
		do: [ :ann | received add: ann ]! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'jf 11/19/2009 16:58'!
testAdded
	self environment announce: (MDElementAdded for: element).
	self assert: (self environment isDirty: slice)! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'cwp 11/25/2009 15:09'!
testDirty
	self subscribeTo: MDSliceDirty.
	self environment announce: (MDElementAdded for: element).
	self deny: received isEmpty.
	self assert: received first slice = slice! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'jf 11/19/2009 16:58'!
testModified
	self environment announce: (MDElementModified for: element).
	self assert: (self environment isDirty: slice)! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'jf 11/19/2009 16:58'!
testRemoved
	self environment announce: (MDElementRemoved for: element).
	self assert: (self environment isDirty: slice)! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'jf 11/25/2009 16:24'!
testRepositoryAdded
	| repository |
	self subscribeTo: MDRepositoryAdded.
	repository := environment addRepository: (MDMemoryRepository named: 'anotherTest').
	self deny: received isEmpty.
	self assert: (received first isKindOf: MDRepositoryAdded).
	self assert: received first environment = self environment.
	self assert: received first repository = repository! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'cwp 2/3/2010 23:04'!
testRepositoryRemoved
	
	| repository |
	repository := MDMemoryRepository forTesting.
	environment addRepository: repository.
	self subscribeTo: MDRepositoryRemoved.
	environment removeRepositoryId: repository id.
	self deny: received isEmpty.
	self assert: (received first isKindOf: MDRepositoryRemoved).
	self assert: received first environment = self environment.
	self assert: received first repository = repository.! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'jf 11/25/2009 16:29'!
testSliceAdded
	| anotherSlice |
	self subscribeTo: MDSliceAdded.
	anotherSlice := environment addSlice: (MDExplicitSlice named: 'anotherTest').
	self deny: received isEmpty.
	self assert: (received first isKindOf: MDSliceAdded).
	self assert: received first environment = self environment.
	self assert: received first slice = anotherSlice.! !

!MDAnnouncementTest methodsFor: 'tests' stamp: 'cwp 2/3/2010 23:04'!
testSliceRemoved
	
	self subscribeTo: MDSliceRemoved.
	environment removeSliceId: slice id.
	self deny: received isEmpty.
	self assert: (received first isKindOf: MDSliceRemoved).
	self assert: received first environment = self environment.
	self assert: received first slice = slice.! !

TestCase subclass: #MDEnvironmentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Interface'!

!MDEnvironmentTest methodsFor: 'as yet unclassified' stamp: 'jf 10/21/2009 16:48'!
testAddRepository
	| environment repository |
	environment := MDEnvironment new.
	repository := environment addRepository: MDMemoryRepository forTesting.
	self assert: (environment repositories includes: repository)! !

!MDEnvironmentTest methodsFor: 'as yet unclassified' stamp: 'jf 10/21/2009 16:34'!
testAddSlice
	| environment slice slice2 |
	environment := MDEnvironment new.
	slice := MDExplicitSlice forTesting.
	slice2 := environment addSlice: slice.
	self assert: (environment slices includes: slice).
	self assert: slice == slice2! !

!MDEnvironmentTest methodsFor: 'as yet unclassified' stamp: 'cwp 8/16/2009 11:08'!
testDefault
	self assert: MDEnvironment default class == MDEnvironment! !

!MDTestBuilder methodsFor: '*mc2-tests-interface' stamp: 'cwp 9/4/2009 16:42'!
merge
	^ self mergeIn: MDEnvironment forTesting! !

!MDTestBuilder methodsFor: '*mc2-tests-interface' stamp: 'cwp 12/16/2007 22:41'!
mergeIn: wc
	
	wc loadVersion: (self versionWith: 'alpha').
	^ MDMerge
		toInclude: (self versionWith: 'beta')
		in: wc.! !
